@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2013 Jeffrey Stedfast
+ *  Copyright (C) 2000-2014 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -317,6 +317,25 @@ g_mime_content_disposition_get_parameter (GMimeContentDisposition *disposition,
 }
 
 
+/**
+ * g_mime_content_disposition_is_attachment:
+ * @disposition: a #GMimeContentDisposition object
+ *
+ * Determines if a Content-Disposition has a value of "attachment".
+ *
+ * Returns: %TRUE if the value matches "attachment", otherwise %FALSE.
+ *
+ * Since: 2.6.21
+ **/
+gboolean
+g_mime_content_disposition_is_attachment (GMimeContentDisposition *disposition)
+{
+	g_return_val_if_fail (GMIME_IS_CONTENT_DISPOSITION (disposition), FALSE);
+	
+	return !g_ascii_strcasecmp (disposition->disposition, "attachment");
+}
+
+
 /**
  * g_mime_content_disposition_to_string:
  * @disposition: a #GMimeContentDisposition object
