@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2013 Jeffrey Stedfast
+ *  Copyright (C) 2000-2014 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -636,7 +636,7 @@ write_references (GMimeStream *stream, const char *name, const char *value)
 	   it seems to break a lot of clients (and servers) */
 	references = g_mime_references_decode (value);
 	folded = g_string_new (name);
-	g_string_append_len (folded, ": ", 2);
+	g_string_append_c (folded, ':');
 	len = folded->len;
 	
 	reference = references;
@@ -978,10 +978,14 @@ message_remove_header (GMimeObject *object, const char *header)
 		break;
 	}
 	
-	if (message->mime_part)
-		g_mime_header_list_set_stream (message->mime_part->headers, NULL);
+	if (GMIME_OBJECT_CLASS (parent_class)->remove_header (object, header)) {
+		if (message->mime_part)
+			g_mime_header_list_set_stream (message->mime_part->headers, NULL);
+		
+		return TRUE;
+	}
 	
-	return GMIME_OBJECT_CLASS (parent_class)->remove_header (object, header);
+	return FALSE;
 }
 
 
@@ -1034,9 +1038,9 @@ message_write_to_stream (GMimeObject *object, GMimeStream *stream)
 			if (!g_mime_header_list_get (object->headers, "MIME-Version")) {
 				if ((nwritten = g_mime_stream_write_string (stream, "MIME-Version: 1.0\n")) == -1)
 					return -1;
+				
+				total += nwritten;
 			}
-			
-			total += nwritten;
 		}
 		
 		if ((nwritten = g_mime_object_write_to_stream (message->mime_part, stream)) == -1)
