@@ -34,6 +34,8 @@
 
 #include "testsuite.h"
 
+#define GPG_PATH "gpg"
+
 extern int verbose;
 
 #define v(x) if (verbose > 3) x
@@ -163,6 +165,11 @@ test_decrypt (GMimeCryptoContext *ctx, gboolean sign, GMimeStream *cleartext, GM
 			ex = exception_new ("unexpected signature");
 	}
 	
+	/* Did not ask for session_key -- it should not be present.
+	   We test asking for session_key over in test-pgpmime.c */
+	if (ex == NULL && result->session_key)
+		ex = exception_new ("got session_key when not requested");
+	
 	g_object_unref (result);
 	
 	if (ex != NULL) {
@@ -283,13 +290,7 @@ int main (int argc, char **argv)
 	
 	testsuite_init (argc, argv);
 	
-	/* reset .gnupg config directory */
-	if (system ("/bin/rm -rf ./tmp") != 0)
-		return EXIT_FAILURE;
-	if (system ("/bin/mkdir ./tmp") != 0)
-		return EXIT_FAILURE;
-	setenv ("GNUPGHOME", "./tmp/.gnupg", 1);
-	if (system ("/usr/bin/gpg --list-keys > /dev/null 2>&1") != 0)
+	if (testsuite_setup_gpghome (GPG_PATH) != 0)
 		return EXIT_FAILURE;
 	
 	for (i = 1; i < argc; i++) {
@@ -304,7 +305,7 @@ int main (int argc, char **argv)
 	
 	testsuite_start ("GnuPG crypto context");
 	
-	ctx = g_mime_gpg_context_new (request_passwd, "/usr/bin/gpg");
+	ctx = g_mime_gpg_context_new (request_passwd, GPG_PATH);
 	g_mime_gpg_context_set_always_trust ((GMimeGpgContext *) ctx, TRUE);
 	
 	testsuite_check ("GMimeGpgContext::import");
@@ -404,7 +405,7 @@ int main (int argc, char **argv)
 	
 	g_mime_shutdown ();
 	
-	if (system ("/bin/rm -rf ./tmp") != 0)
+	if (testsuite_destroy_gpghome () != 0)
 		return EXIT_FAILURE;
 	
 	return testsuite_exit ();
