@@ -27,6 +27,10 @@
 #ifdef ENABLE_THREADS
 #include <pthread.h>
 #endif
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+#include <unistd.h>
 
 #include "testsuite.h"
 
@@ -346,6 +350,77 @@ g_throw (Exception *ex)
 	longjmp (env->env, 1);
 }
 
+/* in versions of gpg before 2.1.16, the only mechanism to override
+   the session key was --override-session-key, which leaks its
+   argument to the process table.
+
+   in 2.1.16, gpg introduced --override-session-key-fd, which is what
+   gmime uses to be safe.
+*/
+
+#define v2_1_16 ((2 << 24) | (1 << 16) | (16 << 8))
+
+int _g_mime_get_gpg_version (const char *gpg);
+
+int
+testsuite_can_safely_override_session_key (const char *gpg)
+{
+	return _g_mime_get_gpg_version (gpg) >= v2_1_16;
+}
+
+int
+testsuite_setup_gpghome (const char *gpg)
+{
+	const char directive[] = "pinentry-mode loopback\n";
+	char *command;
+	
+	/* reset .gnupg config directory */
+	if (system ("/bin/rm -rf ./tmp") != 0)
+		return EXIT_FAILURE;
+	if (system ("/bin/mkdir ./tmp") != 0)
+		return EXIT_FAILURE;
+	
+	g_setenv ("GNUPGHOME", "./tmp/.gnupg", 1);
+	
+	/* disable environment variables that gpg-agent uses for pinentry */
+	g_unsetenv ("DBUS_SESSION_BUS_ADDRESS");
+	g_unsetenv ("DISPLAY");
+	g_unsetenv ("GPG_TTY");
+	
+        command = g_strdup_printf ("%s --list-keys > /dev/null 2>&1", gpg);
+	if (system (command) != 0) {
+		g_free (command);
+		return EXIT_FAILURE;
+	}
+	
+	g_free (command);
+	
+	if (_g_mime_get_gpg_version (gpg) >= ((2 << 24) | (1 << 16))) {
+		FILE *fp;
+		
+		if ((fp = fopen ("./tmp/.gnupg/gpg.conf", "w")) == NULL)
+			return EXIT_FAILURE;
+		
+		if (fwrite (directive, sizeof (directive) - 1, 1, fp) != 1) {
+			fclose (fp);
+			return EXIT_FAILURE;
+		}
+		
+		if (fclose (fp))
+			return EXIT_FAILURE;
+	}
+	
+	return EXIT_SUCCESS;
+}
+
+int
+testsuite_destroy_gpghome (void)
+{
+	if (system ("/bin/rm -rf ./tmp") != 0)
+		return EXIT_FAILURE;
+	return EXIT_SUCCESS;
+}
+
 
 #ifdef BUILD
 int main (int argc, char **argv)
